@@ -75,18 +75,6 @@ clearlooks_draw_gummy_gradient (cairo_t          *cr,
 	cairo_pattern_destroy (pt);
 }
 
-static void
-clearlooks_set_mixed_color (cairo_t          *cr,
-                            const CairoColor *color1,
-                            const CairoColor *color2,
-                            gdouble mix_factor)
-{
-	CairoColor composite;
-
-	ge_mix_color (color1, color2, mix_factor, &composite);
-	ge_cairo_set_color (cr, &composite);
-}
-
 static void
 clearlooks_gummy_draw_highlight_and_shade (cairo_t                *cr,
                                            const CairoColor       *bg_color,
@@ -261,6 +249,7 @@ static void
 clearlooks_gummy_draw_entry (cairo_t                *cr,
                              const ClearlooksColors *colors,
                              const WidgetParameters *params,
+                             const FocusParameters  *focus,
                              int x, int y, int width, int height)
 {
 	const CairoColor *base = &colors->base[params->state_type];
@@ -268,7 +257,7 @@ clearlooks_gummy_draw_entry (cairo_t                *cr,
 	double radius = MIN (params->radius, MIN ((width - 4.0) / 2.0, (height - 4.0) / 2.0));
 
 	if (params->focus)
-		border = colors->spot[2];
+		border = focus->color;
 
 	cairo_save (cr);
 
@@ -285,7 +274,10 @@ clearlooks_gummy_draw_entry (cairo_t                *cr,
 	/* Draw the inner shadow */
 	if (params->focus)
 	{
-		clearlooks_set_mixed_color (cr, base, &colors->spot[1], 0.5);
+		CairoColor focus_shadow;
+		ge_shade_color (&border, 1.61, &focus_shadow);
+		
+		clearlooks_set_mixed_color (cr, base, &focus_shadow, 0.5);
 		ge_cairo_inner_rounded_rectangle (cr, 2, 2, width-4, height-4, MAX(0, radius-1), params->corners);
 		cairo_stroke (cr);
 	}
@@ -987,6 +979,16 @@ clearlooks_gummy_draw_scrollbar_stepper (cairo_t                          *cr,
 			corners = CR_CORNER_TOPLEFT | CR_CORNER_BOTTOMLEFT;
 		else if (stepper->stepper == CL_STEPPER_D)
 			corners = CR_CORNER_TOPRIGHT | CR_CORNER_BOTTOMRIGHT;
+
+		if (stepper->stepper == CL_STEPPER_B)
+		{
+			x -= 1;
+			width += 1;
+		}
+		else if (stepper->stepper == CL_STEPPER_C)
+		{
+			width += 1;
+		}
 	}
 	else
 	{
@@ -994,6 +996,16 @@ clearlooks_gummy_draw_scrollbar_stepper (cairo_t                          *cr,
 			corners = CR_CORNER_TOPLEFT | CR_CORNER_TOPRIGHT;
 		else if (stepper->stepper == CL_STEPPER_D)
 			corners = CR_CORNER_BOTTOMLEFT | CR_CORNER_BOTTOMRIGHT;
+
+		if (stepper->stepper == CL_STEPPER_B)
+		{
+			y -= 1;
+			height += 1;
+		}
+		else if (stepper->stepper == CL_STEPPER_C)
+		{
+			height += 1;
+		}
 	}
 
 	cairo_translate (cr, x, y);
