@@ -1,28 +1,32 @@
-/* Clearlooks theme engine
- * Copyright (C) 2005 Richard Stellingwerff
- * Copyright (C) 2007 Benjamin Berg
- * Copyright (C) 2007 Andrea Cimitan
+/* Clearlooks - a cairo based GTK+ engine
+ * Copyright (C) 2005 Richard Stellingwerff <remenic@gmail.com>
+ * Copyright (C) 2007 Benjamin Berg <benjamin@sipsolutions.net>
+ * Copyright (C) 2007-2008 Andrea Cimitan <andrea.cimitan@gmail.com>
  *
  * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
+ * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
+ * version 2.1 of the License, or (at your option) any later version.
+ * 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * Lesser General Public License for more details.
+ * 
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Project contact: <gnome-themes-list@gnome.org>
  *
- * Written by Owen Taylor <otaylor@redhat.com>
- * and by Alexander Larsson <alexl@redhat.com>
+ *
+ * Originally written by Owen Taylor <otaylor@redhat.com>
+ *                and by Alexander Larsson <alexl@redhat.com>
  * Modified by Richard Stellingwerff <remenic@gmail.com>
  * Modified by Kulyk Nazar <schamane@myeburg.net>
+ *
  */
+ 
 
 #include <string.h>
 #include <widget-information.h>
@@ -31,11 +35,9 @@
 
 #include "animation.h"
 
-static void      clearlooks_rc_style_init         (ClearlooksRcStyle      *style);
 #ifdef HAVE_ANIMATION
 static void      clearlooks_rc_style_finalize     (GObject                *object);
 #endif
-static void      clearlooks_rc_style_class_init   (ClearlooksRcStyleClass *klass);
 static GtkStyle *clearlooks_rc_style_create_style (GtkRcStyle             *rc_style);
 static guint     clearlooks_rc_style_parse        (GtkRcStyle             *rc_style,
                                                    GtkSettings            *settings,
@@ -43,11 +45,6 @@ static guint     clearlooks_rc_style_parse        (GtkRcStyle             *rc_st
 static void      clearlooks_rc_style_merge        (GtkRcStyle             *dest,
                                                    GtkRcStyle             *src);
 
-
-static GtkRcStyleClass *clearlooks_parent_rc_class;
-
-GType clearlooks_type_rc_style = 0;
-
 enum
 {
 	TOKEN_FOCUSCOLOR = G_TOKEN_LAST + 1,
@@ -65,6 +62,7 @@ enum
 	TOKEN_STYLE,
 	TOKEN_RADIUS,
 	TOKEN_HINT,
+	TOKEN_DISABLE_FOCUS,
 
 	TOKEN_CLASSIC,
 	TOKEN_GLOSSY,
@@ -93,6 +91,7 @@ static gchar* clearlooks_rc_symbols =
 	"style\0"
 	"radius\0"
 	"hint\0"
+	"disable_focus\0"
 
 	"CLASSIC\0"
 	"GLOSSY\0"
@@ -102,27 +101,12 @@ static gchar* clearlooks_rc_symbols =
 	"TRUE\0"
 	"FALSE\0";
 
-void
-clearlooks_rc_style_register_type (GTypeModule *module)
-{
-	static const GTypeInfo object_info =
-	{
-		sizeof (ClearlooksRcStyleClass),
-		(GBaseInitFunc) NULL,
-		(GBaseFinalizeFunc) NULL,
-		(GClassInitFunc) clearlooks_rc_style_class_init,
-		NULL,           /* class_finalize */
-		NULL,           /* class_data */
-		sizeof (ClearlooksRcStyle),
-		0,              /* n_preallocs */
-		(GInstanceInitFunc) clearlooks_rc_style_init,
-		NULL
-	};
+G_DEFINE_DYNAMIC_TYPE (ClearlooksRcStyle, clearlooks_rc_style, GTK_TYPE_RC_STYLE)
 
-	clearlooks_type_rc_style = g_type_module_register_type (module,
-	                                                        GTK_TYPE_RC_STYLE,
-	                                                        "ClearlooksRcStyle",
-	                                                        &object_info, 0);
+void
+clearlooks_rc_style_register_types (GTypeModule *module)
+{
+  clearlooks_rc_style_register_type (module);
 }
 
 static void
@@ -140,6 +124,7 @@ clearlooks_rc_style_init (ClearlooksRcStyle *clearlooks_rc)
 	clearlooks_rc->colorize_scrollbar = FALSE;
 	clearlooks_rc->radius = 3.0;
 	clearlooks_rc->hint = 0;
+	clearlooks_rc->disable_focus = FALSE;
 }
 
 #ifdef HAVE_ANIMATION
@@ -149,8 +134,8 @@ clearlooks_rc_style_finalize (GObject *object)
 	/* cleanup all the animation stuff */
 	clearlooks_animation_cleanup ();
 
-	if (G_OBJECT_CLASS (clearlooks_parent_rc_class)->finalize != NULL)
-		G_OBJECT_CLASS (clearlooks_parent_rc_class)->finalize(object);
+	if (G_OBJECT_CLASS (clearlooks_rc_style_parent_class)->finalize != NULL)
+		G_OBJECT_CLASS (clearlooks_rc_style_parent_class)->finalize (object);
 }
 #endif
 
@@ -163,8 +148,6 @@ clearlooks_rc_style_class_init (ClearlooksRcStyleClass *klass)
 	GObjectClass    *g_object_class = G_OBJECT_CLASS (klass);
 #endif
 
-	clearlooks_parent_rc_class = g_type_class_peek_parent (klass);
-
 	rc_style_class->parse = clearlooks_rc_style_parse;
 	rc_style_class->create_style = clearlooks_rc_style_create_style;
 	rc_style_class->merge = clearlooks_rc_style_merge;
@@ -174,6 +157,11 @@ clearlooks_rc_style_class_init (ClearlooksRcStyleClass *klass)
 #endif
 }
 
+static void
+clearlooks_rc_style_class_finalize (ClearlooksRcStyleClass *klass)
+{
+}
+
 static guint
 clearlooks_gtk2_rc_parse_boolean (GtkSettings *settings,
                                   GScanner     *scanner,
@@ -414,6 +402,10 @@ clearlooks_rc_style_parse (GtkRcStyle *rc_style,
 				token = ge_rc_parse_hint (scanner, &clearlooks_style->hint);
 				clearlooks_style->flags |= CL_FLAG_HINT;
 				break;
+			case TOKEN_DISABLE_FOCUS:
+				token = clearlooks_gtk2_rc_parse_boolean (settings, scanner, &clearlooks_style->disable_focus);
+				clearlooks_style->flags |= CL_FLAG_DISABLE_FOCUS;
+				break;
 
 			/* stuff to ignore */
 			case TOKEN_SUNKENMENU:
@@ -455,7 +447,7 @@ clearlooks_rc_style_merge (GtkRcStyle *dest,
 	ClearlooksRcStyle *dest_w, *src_w;
 	ClearlooksRcFlags flags;
 
-	clearlooks_parent_rc_class->merge (dest, src);
+	GTK_RC_STYLE_CLASS (clearlooks_rc_style_parent_class)->merge (dest, src);
 
 	if (!CLEARLOOKS_IS_RC_STYLE (src))
 		return;
@@ -487,6 +479,8 @@ clearlooks_rc_style_merge (GtkRcStyle *dest,
 		dest_w->radius = src_w->radius;
 	if (flags & CL_FLAG_HINT)
 		dest_w->hint = src_w->hint;
+	if (flags & CL_FLAG_DISABLE_FOCUS)
+		dest_w->disable_focus = src_w->disable_focus;
 
 	dest_w->flags |= src_w->flags;
 }
